@@ -18,11 +18,11 @@ Mojo::Pg::Che - mix of parent Mojo::Pg and DBI.pm
 
 =head1 VERSION
 
-Version 0.070
+Version 0.072
 
 =cut
 
-our $VERSION = '0.070';
+our $VERSION = '0.072';
 
 
 =head1 SYNOPSIS
@@ -236,37 +236,6 @@ sub connect {
   return $self;
 }
 
-sub query {
-  my $self = shift;
-  #~ my ($query, $attrs, @bind) = @_;
-  my ($sth, $query) = ref $_[0] ? (shift, undef) : (undef, shift);
-  
-  my $attrs = shift;
-  my $async = delete $attrs->{Async} || delete $attrs->{pg_async};
-  
-  my $cb = ref $_[-1] eq 'CODE' ? pop : undef;
-  my $result;
-  $cb ||= sub {
-    my ($db, $err) = map shift, 1..2;
-    croak "Error on non-blocking query: ",$err
-      if $err;
-    $result = shift;
-    
-  } if $async;
-  
-  my @bind = @_;
-  
-  #~ $sth ||= $self->prepare($query, $attrs, 3); ?????
-  
-  if ($sth) {$result = $self->db($sth->{Database})->execute_sth($sth, @bind, $cb ? ($cb) : ());}
-  else {$result = $self->db->execute_string($query, $attrs, @bind, $cb ? ($cb) : (),);}
-  
-  Mojo::IOLoop->start if $async && not(Mojo::IOLoop->is_running);
-
-  return $result;
-  
-}
-
 sub db {
   my ($self, $dbh) = (shift, shift);
 
@@ -283,6 +252,8 @@ sub prepare_cached { shift->db->prepare_cached(@_); }
 
 sub _db_sth {shift->db(ref $_[0] && $_[0]->{Database})}
 
+sub query { shift->_db_sth(@_)->select(@_) }
+sub select { shift->_db_sth(@_)->select(@_) }
 sub selectrow_array { shift->_db_sth(@_)->selectrow_array(@_) }
 sub selectrow_arrayref { shift->_db_sth(@_)->selectrow_arrayref(@_) }
 sub selectrow_hashref { shift->_db_sth(@_)->selectrow_hashref(@_) }
